@@ -30,3 +30,11 @@ class ImmutableList(tuple):
     remove = complain
     sort = complain
     reverse = complain
+
+
+class ImmutableDict(dict):
+
+    def NotImplemented(self, *args, **kw):
+        raise ValueError("Read Only dict proxy")
+
+    popitem = update = clear = pop = __setitem__ = __delitem__ = NotImplementedError
